@@ -97,12 +97,12 @@ for dir in folders:
 
 os.system("cp ../utils/E-PyoIcon.png source/")
 
-os.system("sphinx-build -a -b %s ./source %s" % (build_format, build_folder))
+os.system("sphinx-build -a -E -j 4 -b %s ./source %s" % (build_format, build_folder))
 
 if build_format == "latex":
     os.system("cd build_latex; pdflatex -interaction nonstopmode Pyo;  pdflatex -interaction nonstopmode Pyo")
 
-rep = raw_input("Do you want to upload to ajax server (y/n) ? ")
+rep = input("Do you want to upload to ajax server (y/n) ? ")
 if rep == "y":
         os.system("scp -r build_html/* jeadum1@ajaxsoundstudio.com:/home/jeadum1/ajaxsoundstudio.com/pyodoc")
 
