@@ -1,5 +1,5 @@
 #include <stdlib.h>
-#include <pd/m_pd.h>
+#include <m_pd.h>
 #include "Python.h"
 #include "m_pyo.h"
 
@@ -73,8 +73,8 @@ void *pyo_tilde_new(t_floatarg f) {
     t_pyo_tilde *x = (t_pyo_tilde *)pd_new(pyo_tilde_class);
 
     x->chnls = (f) ? f : 2;
-    x->bs = -1;
-    x->sr = -1.0;
+    x->bs = 64;
+    x->sr = 44100.0;
     x->file = NULL;
     x->add = 0;
     x->debug = 0;
@@ -93,7 +93,7 @@ void *pyo_tilde_new(t_floatarg f) {
     for (i=0; i<x->chnls; i++)
         x->in[i] = x->out[i] = 0;
 
-    x->interp = pyo_new_interpreter(x->chnls);
+    x->interp = pyo_new_interpreter(x->sr, x->bs, x->chnls);
     
     x->inbuf = (float *)pyo_get_input_buffer_address(x->interp);
     x->outbuf = (float *)pyo_get_output_buffer_address(x->interp);
@@ -177,6 +177,17 @@ void pyo_tilde_create(t_pyo_tilde *x, t_symbol *s, int argc, t_atom *argv) {
         post("pyo~: %s", x->msg);
 }
 
+void pyo_tilde_midi_event(t_pyo_tilde *x, t_symbol *s, int argc, t_atom *argv) {
+    int status = 0, data1 = 0, data2 = 0;
+    if (argc > 0)
+        status = (int)atom_getfloat(argv);
+    if (argc > 1)
+        data1 = (int)atom_getfloat(++argv);
+    if (argc > 2)
+        data2 = (int)atom_getfloat(++argv);
+    pyo_add_midi_event(x->interp, status, data1, data2);
+}
+
 void pyo_tilde_clear(t_pyo_tilde *x) {
     pyo_server_reboot(x->interp);
 }
@@ -244,6 +255,8 @@ void pyo_tilde_setup(void) {
                     A_GIMME, 0); /* call a function or a method */
     class_addmethod(pyo_tilde_class, (t_method)pyo_tilde_create, gensym("create"), 
                     A_GIMME, 0); /* create a python object */
+    class_addmethod(pyo_tilde_class, (t_method)pyo_tilde_midi_event, gensym("midi"), 
+                    A_GIMME, 0); /* create a python object */
     class_addmethod(pyo_tilde_class, (t_method)pyo_tilde_debug, gensym("debug"), 
                     A_DEFFLOAT, 0); /* set the debug (verbose) mode */
     CLASS_MAINSIGNALIN(pyo_tilde_class, t_pyo_tilde, f);
