@@ -7,7 +7,7 @@ Detuned waveguide bank.
 from pyo import *
 import random
 
-s = Server(sr=44100, nchnls=2, buffersize=512, duplex=0).boot()
+s = Server(duplex=0).boot()
 
 src = SfPlayer("../snds/ounkmaster.aif", loop=True, mul=.1)
 
