@@ -6,7 +6,7 @@ Spectral morphing of two sounds.
 """
 from pyo import *
 
-s = Server().boot()
+s = Server(duplex=0).boot()
 
 snd1 = SfPlayer("../snds/baseballmajeur_m.aif", loop=True, mul=.3).mix(2)
 lfos = Sine(freq=[.05,.04], mul=.05, add=[1,.5])
@@ -39,4 +39,9 @@ car = PolToCar(mag, pha)
 fout = IFFT(car["real"], car["imag"], size=size, overlaps=olaps)
 ffout = fout.mix(2).out()
 
+def siz(size=1024):
+    fin1.size = size
+    fin2.size = size
+    fout.size = size
+
 s.gui(locals())
