@@ -6,12 +6,13 @@ Ring modulators used as exciter of a waveguide bank.
 """
 from pyo import *
 
-s = Server().boot()
+s = Server(duplex=0).boot()
 
 tab_m = HarmTable([1,0,0,0,0,.3,0,0,0,0,0,.2,0,0,0,0,0,.1,0,0,0,0,.05]).normalize()
 tab_p = HarmTable([1,0,.33,0,.2,0,.143,0,.111])
 
 class Ring:
+
     def __init__(self, fport=250, fmod=100, amp=.3):
         self.mod = Osc(tab_m, freq=fmod, mul=amp)
         self.port = Osc(tab_p, freq=fport, mul=self.mod)
@@ -19,7 +20,7 @@ class Ring:
     def out(self):
         self.port.out()
         return self
-    
+
     def sig(self):
         return self.port
 
@@ -30,4 +31,4 @@ rg = Ring(fport = [random.choice([62.5,125,187.5,250]) * random.uniform(.99,1.01
 
 res = Waveguide(rg.sig(), freq=[30.1,60.05,119.7,181,242.5,303.33], dur=30, mul=.1).out()
 
-s.gui(locals())
\ No newline at end of file
+s.gui(locals())
