@@ -8,7 +8,7 @@ The PyoObject.get() method can be used to convert audio stream to usable python
 """
 from pyo import *
 
-s = Server(sr=44100, nchnls=2, buffersize=512, duplex=0).boot()
+s = Server(duplex=0).boot()
 
 lfos = Sine(freq=[.1,.2,.4,.3], mul=100, add=500)
 synth = SineLoop(freq=lfos, feedback=.07, mul=.05).out()
