@@ -21,7 +21,7 @@
 #include "Python.h"
 #include <math.h>
 
-#define PYO_VERSION "0.8.6"
+#define PYO_VERSION "0.8.8"
 
 #ifndef __MYFLT_DEF
 #define __MYFLT_DEF
@@ -51,9 +51,13 @@
 #define TYPE_O_IF "O|if"
 #define TYPE_O_IFS "O|ifs"
 #define TYPE_S_IFF "s|iff"
+#define TYPE_P_IFF "s#|iff"
 #define TYPE_S_FIFF "s|fiff"
+#define TYPE_P_FIFF "s#|fiff"
 #define TYPE_S_FFIFF "s|ffiff"
+#define TYPE_P_FFIFF "s#|ffiff"
 #define TYPE_S__OIFI "s|Oifi"
+#define TYPE_P__OIFI "s#|Oifi"
 #define TYPE__FFFOO "|fffOO"
 #define TYPE__FFFIOO "|fffiOO"
 #define TYPE__FFFFFOO "|fffffOO"
@@ -137,9 +141,13 @@
 #define TYPE_O_IF "O|id"
 #define TYPE_O_IFS "O|ids"
 #define TYPE_S_IFF "s|idd"
+#define TYPE_P_IFF "s#|idd"
 #define TYPE_S_FIFF "s|didd"
+#define TYPE_P_FIFF "s#|didd"
 #define TYPE_S_FFIFF "s|ddidd"
+#define TYPE_P_FFIFF "s#|ddidd"
 #define TYPE_S__OIFI "s|Oidi"
+#define TYPE_P__OIFI "s#|Oidi"
 #define TYPE__FFFOO "|dddOO"
 #define TYPE__FFFIOO "|dddiOO"
 #define TYPE__FFFFFOO "|dddddOO"
@@ -613,6 +621,7 @@ extern PyTypeObject TableScanType;
 
 #define pyo_CLEAR \
     if (self->server != NULL) { \
+        Py_DECREF(self->server); \
         self->server = NULL; \
     } \
     if (self->stream != NULL) \
@@ -624,6 +633,7 @@ extern PyTypeObject TableScanType;
 
 #define pyo_table_CLEAR \
     if (self->server != NULL) { \
+        Py_DECREF(self->server); \
         self->server = NULL; \
     } \
     if (self->tablestream != NULL) \
@@ -631,6 +641,7 @@ extern PyTypeObject TableScanType;
 
 #define pyo_matrix_CLEAR \
     if (self->server != NULL) { \
+        Py_DECREF(self->server); \
         self->server = NULL; \
     } \
     if (self->matrixstream != NULL) \
@@ -673,6 +684,7 @@ extern PyTypeObject TableScanType;
 /* Init Server & Stream */
 #define INIT_OBJECT_COMMON \
     self->server = PyServer_get_server(); \
+    Py_INCREF(self->server); \
     self->mul = PyFloat_FromDouble(1); \
     self->add = PyFloat_FromDouble(0); \
     self->bufsize = PyInt_AsLong(PyObject_CallMethod(self->server, "getBufferSize", NULL)); \
@@ -1344,6 +1356,25 @@ extern PyTypeObject TableScanType;
  \
     return PyFloat_FromDouble(self->data[y][x]); \
 
+#define MATRIX_GET_INTERPOLATED \
+    MYFLT x = 0.0, y = 0.0; \
+    static char *kwlist[] = {"x", "y", NULL}; \
+ \
+    if (! PyArg_ParseTupleAndKeywords(args, kwds, TYPE__FF, kwlist, &x, &y)) \
+        return PyInt_FromLong(-1); \
+ \
+    if (x < 0.0 || x > 1.0) { \
+        PyErr_SetString(PyExc_TypeError, "X position outside of matrix boundaries!."); \
+        return PyInt_FromLong(-1); \
+    } \
+ \
+    if (y < 0.0 || y > 1.0) { \
+        PyErr_SetString(PyExc_TypeError, "Y position outside of matrix boundaries!."); \
+        return PyInt_FromLong(-1); \
+    } \
+ \
+    return PyFloat_FromDouble(MatrixStream_getInterpPointFromPos(self->matrixstream, x, y)); \
+
 /* GETS & SETS */
 #define GET_SERVER \
     if (self->server == NULL) { \
