@@ -41,7 +41,8 @@ typedef enum {
 } PyoAudioBackendType;
 
 typedef enum {
-    PyoPortmidi = 0
+    PyoPortmidi = 0,
+    PyoJackMidi = 1
 } PyoMidiBackendType;
 
 /* Portmidi midi message and event type clones. */
@@ -76,8 +77,12 @@ typedef struct {
     int jackautoout; /* jack port auto-connection (on by default) */
     PyObject *jackAutoConnectInputPorts; /* list of lists of jack auto-connection ports to pyo inputs */
     PyObject *jackAutoConnectOutputPorts; /* list of lists of jack auto-connection ports from pyo outputs */
-    PyObject *jackInputPortNames; /* string or list of strings (input port short names for jack server */
-    PyObject *jackOutputPortNames; /* string or list of strings (output port short names for jack server */
+    PyObject *jackInputPortNames; /* string or list of strings (input port short names for jack server) */
+    PyObject *jackOutputPortNames; /* string or list of strings (output port short names for jack server) */
+    PyObject *jackAutoConnectMidiInputPort; /* lists of jack auto-connection ports to pyo midi input */
+    PyObject *jackAutoConnectMidiOutputPort; /* lists of jack auto-connection ports from pyo midi output */
+    PyObject *jackMidiInputPortName; /* string (midi input port short names for jack server) */
+    PyObject *jackMidiOutputPortName; /* string (midi output port short names for jack server) */
     int isJackTransportSlave;
     int jack_transport_state; /* 0 = stopped, 1 = started */
     PyoMidiEvent midiEvents[200];
@@ -100,7 +105,9 @@ typedef struct {
     int midi_output;
     int withPortMidi;
     int withPortMidiOut;
+    int withJackMidi;
     int midiActive;
+    int allowMMMapper;
     int server_started;
     int server_stopped; /* for fadeout */
     int server_booted;
