@@ -1,21 +1,21 @@
-/*************************************************************************
- * Copyright 2010 Olivier Belanger                                        *                  
- *                                                                        * 
+/**************************************************************************
+ * Copyright 2009-2015 Olivier Belanger                                   *
+ *                                                                        *
  * This file is part of pyo, a python module to help digital signal       *
- * processing script creation.                                            *  
- *                                                                        * 
+ * processing script creation.                                            *
+ *                                                                        *
  * pyo is free software: you can redistribute it and/or modify            *
- * it under the terms of the GNU General Public License as published by   *
- * the Free Software Foundation, either version 3 of the License, or      *
- * (at your option) any later version.                                    * 
+ * it under the terms of the GNU Lesser General Public License as         *
+ * published by the Free Software Foundation, either version 3 of the     *
+ * License, or (at your option) any later version.                        *
  *                                                                        *
  * pyo is distributed in the hope that it will be useful,                 *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of         *    
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of         *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- * GNU General Public License for more details.                           *
+ * GNU Lesser General Public License for more details.                    *
  *                                                                        *
- * You should have received a copy of the GNU General Public License      *
- * along with pyo.  If not, see <http://www.gnu.org/licenses/>.           *
+ * You should have received a copy of the GNU Lesser General Public       *
+ * License along with pyo.  If not, see <http://www.gnu.org/licenses/>.   *
  *************************************************************************/
 
 #include <Python.h>
@@ -56,9 +56,8 @@ extern PyTypeObject StreamType;
   (self) = (Stream *)(type)->tp_alloc((type), 0); \
   if ((self) == rt_error) { return rt_error; } \
  \
-  (self)->sid = (self)->chnl = (self)->todac = (self)->bufferCountWait = (self)->bufferCount = (self)->bufsize = (self)->duration = 0; \
-  (self)->active = 1;
-
+  (self)->sid = (self)->chnl = (self)->todac = (self)->bufferCountWait = 0; \
+  (self)->bufferCount = (self)->bufsize = (self)->duration = (self)->active = 0;
 
 typedef struct {
     PyObject_HEAD
@@ -87,6 +86,6 @@ extern PyTypeObject TriggerStreamType;
 #define Stream_setBufferCountWait(op, v) (((Stream *)(op))->bufferCountWait = (v))
 #define Stream_setDuration(op, v) (((Stream *)(op))->duration = (v))
 #define Stream_setBufferSize(op, v) (((Stream *)(op))->bufsize = (v))
- 
+
 #endif
-/* __STREAMMODULE */
+/* __STREAMMODULE */
\ No newline at end of file
