@@ -74,6 +74,7 @@ OBJECTS_TREE = {
                          'pa_get_default_output', 'pm_get_input_devices',
                          'pa_list_devices', 'pa_count_host_apis', 
                          'pa_list_host_apis', 'pa_get_default_host_api',
+                         'pa_get_default_devices_from_host',
                          'pm_count_devices', 'pm_list_devices', 'sndinfo', 
                          'savefile', 'pa_get_output_devices',
                          'pa_get_input_devices', 'midiToHz', 'hzToMidi', 
@@ -94,7 +95,7 @@ OBJECTS_TREE = {
                                   'SquareTable', 'ChebyTable', 'CosTable', 
                                   'CurveTable', 'ExpTable', 'DataTable', 
                                   'WinTable', 'SincTable', 'PartialTable', 
-                                  'AtanTable', 'PadSynthTable']),
+                                  'AtanTable', 'PadSynthTable', 'SharedTable']),
         'PyoPVObject' : sorted(['PVAnal', 'PVSynth', 'PVTranspose', 'PVVerb', 
                                 'PVGate', 'PVAddSynth', 'PVCross', 'PVMult',
                                 'PVMorph', 'PVFilter', 'PVDelay', 'PVBuffer', 
@@ -143,7 +144,8 @@ OBJECTS_TREE = {
                                     'Granule', 'TableRead', 'TableMorph', 
                                     'Looper', 'TableIndex', 'OscBank', 'OscTrig',
                                     'TablePut', 'TableScale', 'Particle', 
-                                    'TableWrite']),
+                                     'Particle2', 'TableWrite', 'TableFill',
+                                     'TableScan']),
             'matrixprocess': sorted(['MatrixRec', 'MatrixPointer', 'MatrixMorph', 
                                      'MatrixRecLoop']),
             'triggers': sorted(['Metro', 'Beat', 'TrigEnv', 'TrigRand', 'Trig', 
@@ -168,6 +170,7 @@ OBJECTS_TREE = {
                                  'SLMapQ', 'SLMapDur', 'SLMapPan'])},
         'Server': [],
         'MidiListener': [],
+        'MidiDispatcher': [],
         'OscListener': [],
         'Stream': [],
         'TableStream': [],
