@@ -27,7 +27,6 @@ License along with pyo.  If not, see <http://www.gnu.org/licenses/>.
 """
 import sys
 import os
-import random
 
 use_wx = 1
 if "PYO_GUI_WX" in os.environ:
@@ -136,7 +135,8 @@ def wxDisplayWindow(f, title):
             MAX_X = x + CURRENT_X
         f.SetPosition((px, py))
     else:
-        f.SetPosition((random.randint(250, 500), random.randint(200, 400)))
+        CURRENT_X, MAX_X, NEXT_Y = 50, 50, 50
+        wxDisplayWindow(f, title)
     f.Show()
 
 def wxShowWindow(f, title, root):
@@ -387,7 +387,7 @@ def createExprEditorWindow(object, title, wxnoserver=False):
             EXPREDITORWINDOWS.append([object, title])
 
 def createServerGUI(nchnls, start, stop, recstart, recstop, setAmp, started,
-                    locals, shutdown, meter, timer, amp, exit, title):
+                    locals, shutdown, meter, timer, amp, exit, title, getIsBooted):
     "Creates the server's GUI."
     global X, Y, MAX_X, NEXT_Y
     if title is None:
@@ -396,13 +396,13 @@ def createServerGUI(nchnls, start, stop, recstart, recstop, setAmp, started,
         createRootWindow()
         win = tkCreateToplevelWindow()
         f = ServerGUI(win, nchnls, start, stop, recstart, recstop, setAmp,
-                      started, locals, shutdown, meter, timer, amp)
+                      started, locals, shutdown, meter, timer, amp, getIsBooted)
         f.master.title(title)
         f.focus_set()
     else:
         win = createRootWindow()
         f = ServerGUI(None, nchnls, start, stop, recstart, recstop, setAmp,
-                      started, locals, shutdown, meter, timer, amp, exit)
+                      started, locals, shutdown, meter, timer, amp, exit, getIsBooted)
         f.SetTitle(title)
         f.SetPosition((30, 30))
         f.Show()
@@ -422,4 +422,4 @@ def createServerGUI(nchnls, start, stop, recstart, recstop, setAmp, started,
         wx.CallAfter(wxCreateDelayedScopeWindows)
         wx.CallAfter(wxCreateDelayedExprEditorWindows)
         wx.CallAfter(f.Raise)
-    return f, win
+    return f, win, PYO_USE_WX
