@@ -45,10 +45,11 @@ class MidiListener(threading.Thread):
         This object is available only if pyo is built with portmidi support
         (see withPortmidi function).
 
-    >>> s = Server().boot()
+    >>> s = Server()
     >>> s.deactivateMidi()
+    >>> s.boot()
     >>> def midicall(status, data1, data2):
-    ...     print status, data1, data2
+    ...     print(status, data1, data2)
     >>> listen = MidiListener(midicall, 5)
     >>> listen.start()
 
@@ -75,6 +76,13 @@ class MidiListener(threading.Thread):
             except:
                 pass
 
+    def stop(self):
+        """
+        Stops the listener and properly close the midi ports.
+
+        """
+        self._listener.stop()
+
     def getDeviceInfos(self):
         """
         Returns infos about connected midi devices.
@@ -131,8 +139,9 @@ class MidiDispatcher(threading.Thread):
         This object is available only if pyo is built with portmidi support
         (see withPortmidi function).
 
-    >>> s = Server().boot()
+    >>> s = Server()
     >>> s.deactivateMidi()
+    >>> s.boot()
     >>> dispatch = MidiDispatcher(5)
     >>> dispatch.start()
     >>> dispatch.send(144, 60, 127)
@@ -262,7 +271,7 @@ class OscListener(threading.Thread):
 
     >>> s = Server().boot()
     >>> def call(address, *args):
-    ...     print address, args
+    ...     print(address, args)
     >>> listen = OscListener(call, 9901)
     >>> listen.start()
 
