@@ -1,3 +1,4 @@
+from __future__ import absolute_import
 """
 Copyright 2009-2015 Olivier Belanger
 
@@ -17,8 +18,8 @@ GNU Lesser General Public License for more details.
 You should have received a copy of the GNU Lesser General Public
 License along with pyo.  If not, see <http://www.gnu.org/licenses/>.
 """
-from _core import *
-from _maps import *
+from ._core import *
+from ._maps import *
 
 ######################################################################
 ### Matrix
@@ -36,11 +37,11 @@ class NewMatrix(PyoMatrixObject):
 
     :Args:
 
-        width : int
+        width: int
             Desired matrix width in samples.
-        height : int
+        height: int
             Desired matrix height in samples.
-        init : list of list of floats, optional
+        init: list of list of floats, optional
             Initial matrix. Defaults to None.
 
     .. seealso::
@@ -60,9 +61,10 @@ class NewMatrix(PyoMatrixObject):
 
     """
     def __init__(self, width, height, init=None):
+        pyoArgsAssert(self, "IIL", width, height, init)
         PyoMatrixObject.__init__(self)
         self._size = (width, height)
-        if init == None:
+        if init is None:
             self._base_objs = [NewMatrix_base(width, height)]
         else:
             self._base_objs = [NewMatrix_base(width, height, init)]
@@ -73,10 +75,11 @@ class NewMatrix(PyoMatrixObject):
 
         :Args:
 
-            x : list of list of floats
+            x: list of list of floats
                 New matrix. Must be of the same size as the actual matrix.
 
         """
+        pyoArgsAssert(self, "l", x)
         [obj.setMatrix(x) for obj in self._base_objs]
         self.refreshView()
 
@@ -94,13 +97,14 @@ class NewMatrix(PyoMatrixObject):
 
         :Args:
 
-            freq : float
+            freq: float
                 Frequency of sinusoids used to created the terrain.
                 Defaults to 1.
-            phase : float
+            phase: float
                 Phase deviation between rows of the terrain. Should be in
                 the range 0 -> 1. Defaults to 0.0625.
 
         """
+        pyoArgsAssert(self, "NN", freq, phase)
         [obj.genSineTerrain(freq, phase) for obj in self._base_objs]
-        self.refreshView()
\ No newline at end of file
+        self.refreshView()
