@@ -26,7 +26,7 @@ GNU Lesser General Public License for more details.
 You should have received a copy of the GNU Lesser General Public
 License along with pyo.  If not, see <http://www.gnu.org/licenses/>.
 """
-import sys, random
+import sys
 from ._core import *
 from ._maps import *
 
@@ -670,9 +670,9 @@ class Mixer(PyoObject):
         """
         pyoArgsAssert(self, "o", input)
         if voice is None:
-            voice = random.randint(0, 32767)
+            voice = get_random_integer(mx=32767)
             while voice in self._inputs:
-                voice = random.randint(0, 32767)
+                voice = get_random_integer(mx=32767)
         if voice in self._inputs:
             print("Mixer has already a key named %s" % voice, file=sys.stderr)
             return
