@@ -83,7 +83,7 @@ class SfPlayer(PyoObject):
         the first stream to the next object:
 
         >>> def printing():
-        ...     print "one trig!"
+        ...     print("one trig!")
         >>> sf = SfPlayer("/stereo/sound/file.aif").out()
         >>> trig = TrigFunc(sf['trig'][0], printing)
 
@@ -106,8 +106,8 @@ class SfPlayer(PyoObject):
         self._base_objs = []
         _trig_objs_tmp = []
         for i in range(lmax):
-            _snd_size, _dur, _snd_sr, _snd_chnls, _format, _type  = sndinfo(path[0])
-            self._base_players.append(SfPlayer_base(wrap(path,i), wrap(speed,i), wrap(loop,i), wrap(offset,i), wrap(interp,i)))
+            _snd_size, _dur, _snd_sr, _snd_chnls, _format, _type = sndinfo(path[0])
+            self._base_players.append(SfPlayer_base(stringencode(wrap(path,i)), wrap(speed,i), wrap(loop,i), wrap(offset,i), wrap(interp,i)))
             for j in range(_snd_chnls):
                 self._base_objs.append(SfPlay_base(self._base_players[-1], j, wrap(mul,i), wrap(add,i)))
                 _trig_objs_tmp.append(TriggerDummy_base(self._base_players[-1]))
@@ -146,7 +146,7 @@ class SfPlayer(PyoObject):
 
         self._path = path
         path, lmax = convertArgsToLists(path)
-        [obj.setSound(wrap(path,i)) for i, obj in enumerate(self._base_players)]
+        [obj.setSound(stringencode(wrap(path,i))) for i, obj in enumerate(self._base_players)]
 
     def setSound(self, path):
         """
@@ -330,13 +330,13 @@ class SfMarkerShuffler(PyoObject):
         self._snd_size, self._dur, self._snd_sr, self._snd_chnls, _format, _type = sndinfo(path[0])
         for i in range(lmax):
             try:
-                sf = aifc.open(wrap(path,i))
+                sf = aifc.open(wrap(path,i)) # Do we need stringencode() here?
                 markerstmp = sf.getmarkers()
                 sf.close()
                 self._markers = [m[1] for m in markerstmp]
             except:
                 self._markers = []
-            self._base_players.append(SfMarkerShuffler_base(wrap(path,i), self._markers, wrap(speed,i), wrap(interp,i)))
+            self._base_players.append(SfMarkerShuffler_base(stringencode(wrap(path,i)), self._markers, wrap(speed,i), wrap(interp,i)))
         for i in range(lmax * self._snd_chnls):
             j = i // self._snd_chnls
             self._base_objs.append(SfMarkerShuffle_base(wrap(self._base_players,j), i % self._snd_chnls, wrap(mul,j), wrap(add,j)))
@@ -520,7 +520,7 @@ class SfMarkerLooper(PyoObject):
                 self._markers = [m[1] for m in markerstmp]
             except:
                 self._markers = []
-            self._base_players.append(SfMarkerLooper_base(wrap(path,i), self._markers, wrap(speed,i), wrap(mark,i), wrap(interp,i)))
+            self._base_players.append(SfMarkerLooper_base(stringencode(wrap(path,i)), self._markers, wrap(speed,i), wrap(mark,i), wrap(interp,i)))
         for i in range(lmax * self._snd_chnls):
             j = i // self._snd_chnls
             self._base_objs.append(SfMarkerLoop_base(wrap(self._base_players,j), i % self._snd_chnls, wrap(mul,j), wrap(add,j)))
