@@ -1,24 +1,25 @@
-/*************************************************************************
-* Copyright 2010 Olivier Belanger                                        *                  
-*                                                                        * 
-* This file is part of pyo, a python module to help digital signal       *
-* processing script creation.                                            *  
-*                                                                        * 
-* pyo is free software: you can redistribute it and/or modify            *
-* it under the terms of the GNU General Public License as published by   *
-* the Free Software Foundation, either version 3 of the License, or      *
-* (at your option) any later version.                                    * 
-*                                                                        *
-* pyo is distributed in the hope that it will be useful,                 *
-* but WITHOUT ANY WARRANTY; without even the implied warranty of         *    
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
-* GNU General Public License for more details.                           *
-*                                                                        *
-* You should have received a copy of the GNU General Public License      *
-* along with pyo.  If not, see <http://www.gnu.org/licenses/>.           *
-*************************************************************************/
+/**************************************************************************
+ * Copyright 2009-2015 Olivier Belanger                                   *
+ *                                                                        *
+ * This file is part of pyo, a python module to help digital signal       *
+ * processing script creation.                                            *
+ *                                                                        *
+ * pyo is free software: you can redistribute it and/or modify            *
+ * it under the terms of the GNU Lesser General Public License as         *
+ * published by the Free Software Foundation, either version 3 of the     *
+ * License, or (at your option) any later version.                        *
+ *                                                                        *
+ * pyo is distributed in the hope that it will be useful,                 *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of         *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
+ * GNU Lesser General Public License for more details.                    *
+ *                                                                        *
+ * You should have received a copy of the GNU Lesser General Public       *
+ * License along with pyo.  If not, see <http://www.gnu.org/licenses/>.   *
+ *************************************************************************/
 
 #include <Python.h>
+#include "py2to3.h"
 #include "structmember.h"
 #include <math.h>
 #include "pyomodule.h"
@@ -43,31 +44,31 @@ Dummy_setProcMode(Dummy *self)
     muladdmode = self->modebuffer[0] + self->modebuffer[1] * 10;
 
 	switch (muladdmode) {
-        case 0:        
+        case 0:
             self->muladd_func_ptr = Dummy_postprocessing_ii;
             break;
-        case 1:    
+        case 1:
             self->muladd_func_ptr = Dummy_postprocessing_ai;
             break;
-        case 2:    
+        case 2:
             self->muladd_func_ptr = Dummy_postprocessing_revai;
             break;
-        case 10:        
+        case 10:
             self->muladd_func_ptr = Dummy_postprocessing_ia;
             break;
-        case 11:    
+        case 11:
             self->muladd_func_ptr = Dummy_postprocessing_aa;
             break;
-        case 12:    
+        case 12:
             self->muladd_func_ptr = Dummy_postprocessing_revaa;
             break;
-        case 20:        
+        case 20:
             self->muladd_func_ptr = Dummy_postprocessing_ireva;
             break;
-        case 21:    
+        case 21:
             self->muladd_func_ptr = Dummy_postprocessing_areva;
             break;
-        case 22:    
+        case 22:
             self->muladd_func_ptr = Dummy_postprocessing_revareva;
             break;
     }
@@ -80,7 +81,7 @@ Dummy_compute_next_data_frame(Dummy *self)
     MYFLT *in = Stream_getData((Stream *)self->input_stream);
     for (i=0; i<self->bufsize; i++) {
         self->data[i] = in[i];
-    }    
+    }
     (*self->muladd_func_ptr)(self);
 }
 
@@ -93,7 +94,7 @@ Dummy_traverse(Dummy *self, visitproc visit, void *arg)
     return 0;
 }
 
-static int 
+static int
 Dummy_clear(Dummy *self)
 {
     pyo_CLEAR
@@ -107,24 +108,24 @@ Dummy_dealloc(Dummy* self)
 {
     pyo_DEALLOC
     Dummy_clear(self);
-    self->ob_type->tp_free((PyObject*)self);
+    Py_TYPE(self)->tp_free((PyObject*)self);
 }
 
-PyObject * 
+PyObject *
 Dummy_initialize(Dummy *self)
 {
     int i;
 	self->modebuffer[0] = 0;
 	self->modebuffer[1] = 0;
-    
+
     INIT_OBJECT_COMMON
     Stream_setFunctionPtr(self->stream, Dummy_compute_next_data_frame);
     self->mode_func_ptr = Dummy_setProcMode;
-    
+
     PyObject_CallMethod(self->server, "addStream", "O", self->stream);
 
     Stream_setStreamActive(self->stream, 1);
-    
+
     Py_INCREF(Py_None);
     return Py_None;
 }
@@ -146,17 +147,17 @@ Dummy_setInput(Dummy *self, PyObject *arg)
     (*self->mode_func_ptr)(self);
 
     Dummy_compute_next_data_frame(self);
-    
+
     Py_INCREF(Py_None);
     return Py_None;
 }
 
 static PyObject * Dummy_getServer(Dummy* self) { GET_SERVER };
 static PyObject * Dummy_getStream(Dummy* self) { GET_STREAM };
-static PyObject * Dummy_setMul(Dummy *self, PyObject *arg) { SET_MUL };	
-static PyObject * Dummy_setAdd(Dummy *self, PyObject *arg) { SET_ADD };	
-static PyObject * Dummy_setSub(Dummy *self, PyObject *arg) { SET_SUB };	
-static PyObject * Dummy_setDiv(Dummy *self, PyObject *arg) { SET_DIV };	
+static PyObject * Dummy_setMul(Dummy *self, PyObject *arg) { SET_MUL };
+static PyObject * Dummy_setAdd(Dummy *self, PyObject *arg) { SET_ADD };
+static PyObject * Dummy_setSub(Dummy *self, PyObject *arg) { SET_SUB };
+static PyObject * Dummy_setDiv(Dummy *self, PyObject *arg) { SET_DIV };
 
 static PyObject * Dummy_play(Dummy *self, PyObject *args, PyObject *kwds) { PLAY };
 static PyObject * Dummy_out(Dummy *self, PyObject *args, PyObject *kwds) { OUT };
@@ -198,7 +199,7 @@ static PyNumberMethods Dummy_as_number = {
     (binaryfunc)Dummy_add,                         /*nb_add*/
     (binaryfunc)Dummy_sub,                         /*nb_subtract*/
     (binaryfunc)Dummy_multiply,                    /*nb_multiply*/
-    (binaryfunc)Dummy_div,                          /*nb_divide*/
+    INITIALIZE_NB_DIVIDE_ZERO   /*nb_divide*/
     0,                                              /*nb_remainder*/
     0,                                              /*nb_divmod*/
     0,                                              /*nb_power*/
@@ -212,16 +213,16 @@ static PyNumberMethods Dummy_as_number = {
     0,                                              /*nb_and*/
     0,                                              /*nb_xor*/
     0,                                              /*nb_or*/
-    0,                                              /*nb_coerce*/
+    INITIALIZE_NB_COERCE_ZERO                       /*nb_coerce*/
     0,                                              /*nb_int*/
     0,                                              /*nb_long*/
     0,                                              /*nb_float*/
-    0,                                              /*nb_oct*/
-    0,                                              /*nb_hex*/
+    INITIALIZE_NB_OCT_ZERO                          /*nb_oct*/
+    INITIALIZE_NB_HEX_ZERO                          /*nb_hex*/
     (binaryfunc)Dummy_inplace_add,                 /*inplace_add*/
     (binaryfunc)Dummy_inplace_sub,                 /*inplace_subtract*/
     (binaryfunc)Dummy_inplace_multiply,            /*inplace_multiply*/
-    (binaryfunc)Dummy_inplace_div,                  /*inplace_divide*/
+    INITIALIZE_NB_IN_PLACE_DIVIDE_ZERO               /*inplace_divide*/
     0,                                              /*inplace_remainder*/
     0,                                              /*inplace_power*/
     0,                                              /*inplace_lshift*/
@@ -230,15 +231,14 @@ static PyNumberMethods Dummy_as_number = {
     0,                                              /*inplace_xor*/
     0,                                              /*inplace_or*/
     0,                                              /*nb_floor_divide*/
-    0,                                              /*nb_true_divide*/
+    (binaryfunc)Dummy_div,                       /*nb_true_divide*/
     0,                                              /*nb_inplace_floor_divide*/
-    0,                                              /*nb_inplace_true_divide*/
+    (binaryfunc)Dummy_inplace_div,                       /*nb_inplace_true_divide*/
     0,                                              /* nb_index */
 };
 
 PyTypeObject DummyType = {
-    PyObject_HEAD_INIT(NULL)
-    0,                                              /*ob_size*/
+    PyVarObject_HEAD_INIT(NULL, 0)
     "_pyo.Dummy_base",                                   /*tp_name*/
     sizeof(Dummy),                                 /*tp_basicsize*/
     0,                                              /*tp_itemsize*/
@@ -246,7 +246,7 @@ PyTypeObject DummyType = {
     0,                                              /*tp_print*/
     0,                                              /*tp_getattr*/
     0,                                              /*tp_setattr*/
-    0,                                              /*tp_compare*/
+    0,                                              /*tp_as_async (tp_compare in Python 2)*/
     0,                                              /*tp_repr*/
     &Dummy_as_number,                              /*tp_as_number*/
     0,                                              /*tp_as_sequence*/
@@ -302,36 +302,36 @@ static void
 TriggerDummy_setProcMode(TriggerDummy *self) {
     int muladdmode;
     muladdmode = self->modebuffer[0] + self->modebuffer[1] * 10;
-    
+
     switch (muladdmode) {
-        case 0:        
+        case 0:
             self->muladd_func_ptr = TriggerDummy_postprocessing_ii;
             break;
-        case 1:    
+        case 1:
             self->muladd_func_ptr = TriggerDummy_postprocessing_ai;
             break;
-        case 2:    
+        case 2:
             self->muladd_func_ptr = TriggerDummy_postprocessing_revai;
             break;
-        case 10:        
+        case 10:
             self->muladd_func_ptr = TriggerDummy_postprocessing_ia;
             break;
-        case 11:    
+        case 11:
             self->muladd_func_ptr = TriggerDummy_postprocessing_aa;
             break;
-        case 12:    
+        case 12:
             self->muladd_func_ptr = TriggerDummy_postprocessing_revaa;
             break;
-        case 20:        
+        case 20:
             self->muladd_func_ptr = TriggerDummy_postprocessing_ireva;
             break;
-        case 21:    
+        case 21:
             self->muladd_func_ptr = TriggerDummy_postprocessing_areva;
             break;
-        case 22:    
+        case 22:
             self->muladd_func_ptr = TriggerDummy_postprocessing_revareva;
             break;
-    }  
+    }
 }
 
 static void
@@ -341,7 +341,7 @@ TriggerDummy_compute_next_data_frame(TriggerDummy *self)
     MYFLT *tmp = TriggerStream_getData((TriggerStream *)self->input_stream);
     for (i=0; i<self->bufsize; i++) {
         self->data[i] = tmp[i];
-    }    
+    }
     (*self->muladd_func_ptr)(self);
 }
 
@@ -354,11 +354,11 @@ TriggerDummy_traverse(TriggerDummy *self, visitproc visit, void *arg)
     return 0;
 }
 
-static int 
+static int
 TriggerDummy_clear(TriggerDummy *self)
 {
     pyo_CLEAR
-    Py_CLEAR(self->input);    
+    Py_CLEAR(self->input);
     Py_CLEAR(self->input_stream);
     return 0;
 }
@@ -368,7 +368,7 @@ TriggerDummy_dealloc(TriggerDummy* self)
 {
     pyo_DEALLOC
     TriggerDummy_clear(self);
-    self->ob_type->tp_free((PyObject*)self);
+    Py_TYPE(self)->tp_free((PyObject*)self);
 }
 
 static PyObject *
@@ -378,34 +378,34 @@ TriggerDummy_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
     PyObject *inputtmp, *input_streamtmp;
     TriggerDummy *self;
     self = (TriggerDummy *)type->tp_alloc(type, 0);
-    
+
     self->modebuffer[0] = 0;
     self->modebuffer[1] = 0;
-    
+
     INIT_OBJECT_COMMON
     Stream_setFunctionPtr(self->stream, TriggerDummy_compute_next_data_frame);
     self->mode_func_ptr = TriggerDummy_setProcMode;
 
     static char *kwlist[] = {"input", NULL};
-    
+
     if (! PyArg_ParseTupleAndKeywords(args, kwds, "O", kwlist, &inputtmp))
-        Py_RETURN_NONE; 
-    
+        Py_RETURN_NONE;
+
     INIT_INPUT_TRIGGER_STREAM
-    
+
     PyObject_CallMethod(self->server, "addStream", "O", self->stream);
-    
+
     (*self->mode_func_ptr)(self);
-    
+
     return (PyObject *)self;
 }
 
 static PyObject * TriggerDummy_getServer(TriggerDummy* self) { GET_SERVER };
 static PyObject * TriggerDummy_getStream(TriggerDummy* self) { GET_STREAM };
-static PyObject * TriggerDummy_setMul(TriggerDummy *self, PyObject *arg) { SET_MUL };	
-static PyObject * TriggerDummy_setAdd(TriggerDummy *self, PyObject *arg) { SET_ADD };	
-static PyObject * TriggerDummy_setSub(TriggerDummy *self, PyObject *arg) { SET_SUB };	
-static PyObject * TriggerDummy_setDiv(TriggerDummy *self, PyObject *arg) { SET_DIV };	
+static PyObject * TriggerDummy_setMul(TriggerDummy *self, PyObject *arg) { SET_MUL };
+static PyObject * TriggerDummy_setAdd(TriggerDummy *self, PyObject *arg) { SET_ADD };
+static PyObject * TriggerDummy_setSub(TriggerDummy *self, PyObject *arg) { SET_SUB };
+static PyObject * TriggerDummy_setDiv(TriggerDummy *self, PyObject *arg) { SET_DIV };
 
 static PyObject * TriggerDummy_play(TriggerDummy *self, PyObject *args, PyObject *kwds) { PLAY };
 static PyObject * TriggerDummy_stop(TriggerDummy *self) { STOP };
@@ -435,14 +435,14 @@ static PyMethodDef TriggerDummy_methods[] = {
     {"setMul", (PyCFunction)TriggerDummy_setMul, METH_O, "Sets oscillator mul factor."},
     {"setAdd", (PyCFunction)TriggerDummy_setAdd, METH_O, "Sets oscillator add factor."},
     {"setSub", (PyCFunction)TriggerDummy_setSub, METH_O, "Sets inverse add factor."},
-    {"setDiv", (PyCFunction)TriggerDummy_setDiv, METH_O, "Sets inverse mul factor."},        
+    {"setDiv", (PyCFunction)TriggerDummy_setDiv, METH_O, "Sets inverse mul factor."},
     {NULL}  /* Sentinel */
 };
 static PyNumberMethods TriggerDummy_as_number = {
     (binaryfunc)TriggerDummy_add,                         /*nb_add*/
     (binaryfunc)TriggerDummy_sub,                         /*nb_subtract*/
     (binaryfunc)TriggerDummy_multiply,                    /*nb_multiply*/
-    (binaryfunc)TriggerDummy_div,                                              /*nb_divide*/
+    INITIALIZE_NB_DIVIDE_ZERO                       /*nb_divide*/
     0,                                              /*nb_remainder*/
     0,                                              /*nb_divmod*/
     0,                                              /*nb_power*/
@@ -456,16 +456,16 @@ static PyNumberMethods TriggerDummy_as_number = {
     0,                                              /*nb_and*/
     0,                                              /*nb_xor*/
     0,                                              /*nb_or*/
-    0,                                              /*nb_coerce*/
+    INITIALIZE_NB_COERCE_ZERO                       /*nb_coerce*/
     0,                                              /*nb_int*/
     0,                                              /*nb_long*/
     0,                                              /*nb_float*/
-    0,                                              /*nb_oct*/
-    0,                                              /*nb_hex*/
+    INITIALIZE_NB_OCT_ZERO                          /*nb_oct*/
+    INITIALIZE_NB_HEX_ZERO                          /*nb_hex*/
     (binaryfunc)TriggerDummy_inplace_add,                 /*inplace_add*/
     (binaryfunc)TriggerDummy_inplace_sub,                 /*inplace_subtract*/
     (binaryfunc)TriggerDummy_inplace_multiply,            /*inplace_multiply*/
-    (binaryfunc)TriggerDummy_inplace_div,                                              /*inplace_divide*/
+    INITIALIZE_NB_IN_PLACE_DIVIDE_ZERO                                           /*inplace_divide*/
     0,                                              /*inplace_remainder*/
     0,                                              /*inplace_power*/
     0,                                              /*inplace_lshift*/
@@ -474,15 +474,14 @@ static PyNumberMethods TriggerDummy_as_number = {
     0,                                              /*inplace_xor*/
     0,                                              /*inplace_or*/
     0,                                              /*nb_floor_divide*/
-    0,                                              /*nb_true_divide*/
+    (binaryfunc)TriggerDummy_div,                       /*nb_true_divide*/
     0,                                              /*nb_inplace_floor_divide*/
-    0,                                              /*nb_inplace_true_divide*/
+    (binaryfunc)TriggerDummy_inplace_div,                       /*nb_inplace_true_divide*/
     0,                                              /* nb_index */
 };
 
 PyTypeObject TriggerDummyType = {
-    PyObject_HEAD_INIT(NULL)
-    0,                         /*ob_size*/
+    PyVarObject_HEAD_INIT(NULL, 0)
     "_pyo.TriggerDummy_base",         /*tp_name*/
     sizeof(TriggerDummy),         /*tp_basicsize*/
     0,                         /*tp_itemsize*/
@@ -490,7 +489,7 @@ PyTypeObject TriggerDummyType = {
     0,                         /*tp_print*/
     0,                         /*tp_getattr*/
     0,                         /*tp_setattr*/
-    0,                         /*tp_compare*/
+    0,                         /*tp_as_async (tp_compare in Python 2)*/
     0,                         /*tp_repr*/
     &TriggerDummy_as_number,             /*tp_as_number*/
     0,                         /*tp_as_sequence*/
@@ -520,4 +519,4 @@ PyTypeObject TriggerDummyType = {
     0,      /* tp_init */
     0,                         /* tp_alloc */
     TriggerDummy_new,                 /* tp_new */
-};
+};
\ No newline at end of file
