@@ -1,24 +1,25 @@
-/*************************************************************************
- * Copyright 2010 Olivier Belanger                                        *                  
- *                                                                        * 
+/**************************************************************************
+ * Copyright 2009-2015 Olivier Belanger                                   *
+ *                                                                        *
  * This file is part of pyo, a python module to help digital signal       *
- * processing script creation.                                            *  
- *                                                                        * 
+ * processing script creation.                                            *
+ *                                                                        *
  * pyo is free software: you can redistribute it and/or modify            *
- * it under the terms of the GNU General Public License as published by   *
- * the Free Software Foundation, either version 3 of the License, or      *
- * (at your option) any later version.                                    * 
+ * it under the terms of the GNU Lesser General Public License as         *
+ * published by the Free Software Foundation, either version 3 of the     *
+ * License, or (at your option) any later version.                        *
  *                                                                        *
  * pyo is distributed in the hope that it will be useful,                 *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of         *    
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of         *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- * GNU General Public License for more details.                           *
+ * GNU Lesser General Public License for more details.                    *
  *                                                                        *
- * You should have received a copy of the GNU General Public License      *
- * along with pyo.  If not, see <http://www.gnu.org/licenses/>.           *
+ * You should have received a copy of the GNU Lesser General Public       *
+ * License along with pyo.  If not, see <http://www.gnu.org/licenses/>.   *
  *************************************************************************/
 
 #include <Python.h>
+#include "py2to3.h"
 #include "structmember.h"
 #include <math.h>
 #include "pyomodule.h"
@@ -49,39 +50,39 @@ Mix_setProcMode(Mix *self)
     muladdmode = self->modebuffer[0] + self->modebuffer[1] * 10;
 
 	switch (muladdmode) {
-        case 0:        
+        case 0:
             self->muladd_func_ptr = Mix_postprocessing_ii;
             break;
-        case 1:    
+        case 1:
             self->muladd_func_ptr = Mix_postprocessing_ai;
             break;
-        case 2:    
+        case 2:
             self->muladd_func_ptr = Mix_postprocessing_revai;
             break;
-        case 10:        
+        case 10:
             self->muladd_func_ptr = Mix_postprocessing_ia;
             break;
-        case 11:    
+        case 11:
             self->muladd_func_ptr = Mix_postprocessing_aa;
             break;
-        case 12:    
+        case 12:
             self->muladd_func_ptr = Mix_postprocessing_revaa;
             break;
-        case 20:        
+        case 20:
             self->muladd_func_ptr = Mix_postprocessing_ireva;
             break;
-        case 21:    
+        case 21:
             self->muladd_func_ptr = Mix_postprocessing_areva;
             break;
-        case 22:    
+        case 22:
             self->muladd_func_ptr = Mix_postprocessing_revareva;
             break;
-    }   
+    }
 }
 
 static void
 Mix_compute_next_data_frame(Mix *self)
-{   
+{
     int i, j;
     MYFLT old;
     PyObject *stream;
@@ -96,13 +97,13 @@ Mix_compute_next_data_frame(Mix *self)
         for (j=0; j<self->bufsize; j++) {
             old = buffer[j];
             buffer[j] = in[j] + old;
-        }    
-    }    
-    
+        }
+    }
+
     for (i=0; i<self->bufsize; i++) {
         self->data[i] = buffer[i];
     }
-    
+
     (*self->muladd_func_ptr)(self);
 }
 
@@ -114,7 +115,7 @@ Mix_traverse(Mix *self, visitproc visit, void *arg)
     return 0;
 }
 
-static int 
+static int
 Mix_clear(Mix *self)
 {
     pyo_CLEAR
@@ -127,7 +128,7 @@ Mix_dealloc(Mix* self)
 {
     pyo_DEALLOC
     Mix_clear(self);
-    self->ob_type->tp_free((PyObject*)self);
+    Py_TYPE(self)->tp_free((PyObject*)self);
 }
 
 static PyObject *
@@ -148,12 +149,12 @@ Mix_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
     static char *kwlist[] = {"input", "mul", "add", NULL};
 
     if (! PyArg_ParseTupleAndKeywords(args, kwds, "O|OO", kwlist, &inputtmp, &multmp, &addtmp))
-        Py_RETURN_NONE; 
+        Py_RETURN_NONE;
 
     Py_INCREF(inputtmp);
     Py_XDECREF(self->input);
     self->input = inputtmp;
-    
+
     if (multmp) {
         PyObject_CallMethod((PyObject *)self, "setMul", "O", multmp);
     }
@@ -161,19 +162,19 @@ Mix_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
     if (addtmp) {
         PyObject_CallMethod((PyObject *)self, "setAdd", "O", addtmp);
     }
-            
+
     PyObject_CallMethod(self->server, "addStream", "O", self->stream);
 
     (*self->mode_func_ptr)(self);
-    
+
     return (PyObject *)self;
 }
 
 static PyObject * Mix_getServer(Mix* self) { GET_SERVER };
 static PyObject * Mix_getStream(Mix* self) { GET_STREAM };
-static PyObject * Mix_setMul(Mix *self, PyObject *arg) { SET_MUL };	
-static PyObject * Mix_setAdd(Mix *self, PyObject *arg) { SET_ADD };	
-static PyObject * Mix_setSub(Mix *self, PyObject *arg) { SET_SUB };	
+static PyObject * Mix_setMul(Mix *self, PyObject *arg) { SET_MUL };
+static PyObject * Mix_setAdd(Mix *self, PyObject *arg) { SET_ADD };
+static PyObject * Mix_setSub(Mix *self, PyObject *arg) { SET_SUB };
 static PyObject * Mix_setDiv(Mix *self, PyObject *arg) { SET_DIV };
 
 static PyObject * Mix_play(Mix *self, PyObject *args, PyObject *kwds) { PLAY };
@@ -215,7 +216,7 @@ static PyNumberMethods Mix_as_number = {
     (binaryfunc)Mix_add,                      /*nb_add*/
     (binaryfunc)Mix_sub,                 /*nb_subtract*/
     (binaryfunc)Mix_multiply,                 /*nb_multiply*/
-    (binaryfunc)Mix_div,                   /*nb_divide*/
+    INITIALIZE_NB_DIVIDE_ZERO               /*nb_divide*/
     0,                /*nb_remainder*/
     0,                   /*nb_divmod*/
     0,                   /*nb_power*/
@@ -229,16 +230,16 @@ static PyNumberMethods Mix_as_number = {
     0,              /*nb_and*/
     0,              /*nb_xor*/
     0,               /*nb_or*/
-    0,                                          /*nb_coerce*/
+    INITIALIZE_NB_COERCE_ZERO                   /*nb_coerce*/
     0,                       /*nb_int*/
     0,                      /*nb_long*/
     0,                     /*nb_float*/
-    0,                       /*nb_oct*/
-    0,                       /*nb_hex*/
+    INITIALIZE_NB_OCT_ZERO   /*nb_oct*/
+    INITIALIZE_NB_HEX_ZERO   /*nb_hex*/
     (binaryfunc)Mix_inplace_add,              /*inplace_add*/
     (binaryfunc)Mix_inplace_sub,         /*inplace_subtract*/
     (binaryfunc)Mix_inplace_multiply,         /*inplace_multiply*/
-    (binaryfunc)Mix_inplace_div,           /*inplace_divide*/
+    INITIALIZE_NB_IN_PLACE_DIVIDE_ZERO        /*inplace_divide*/
     0,        /*inplace_remainder*/
     0,           /*inplace_power*/
     0,       /*inplace_lshift*/
@@ -247,15 +248,14 @@ static PyNumberMethods Mix_as_number = {
     0,      /*inplace_xor*/
     0,       /*inplace_or*/
     0,             /*nb_floor_divide*/
-    0,              /*nb_true_divide*/
+    (binaryfunc)Mix_div,                       /*nb_true_divide*/
     0,     /*nb_inplace_floor_divide*/
-    0,      /*nb_inplace_true_divide*/
+    (binaryfunc)Mix_inplace_div,                       /*nb_inplace_true_divide*/
     0,                     /* nb_index */
 };
 
 PyTypeObject MixType = {
-    PyObject_HEAD_INIT(NULL)
-    0,                         /*ob_size*/
+    PyVarObject_HEAD_INIT(NULL, 0)
     "_pyo.Mix_base",         /*tp_name*/
     sizeof(Mix),         /*tp_basicsize*/
     0,                         /*tp_itemsize*/
@@ -263,7 +263,7 @@ PyTypeObject MixType = {
     0,                         /*tp_print*/
     0,                         /*tp_getattr*/
     0,                         /*tp_setattr*/
-    0,                         /*tp_compare*/
+    0,                         /*tp_as_async (tp_compare in Python 2)*/
     0,                         /*tp_repr*/
     &Mix_as_number,             /*tp_as_number*/
     0,                         /*tp_as_sequence*/
@@ -294,4 +294,3 @@ PyTypeObject MixType = {
     0,                         /* tp_alloc */
     Mix_new,                 /* tp_new */
 };
-
