@@ -36,6 +36,8 @@ typedef struct {
     MYFLT release;
     MYFLT duration;
     MYFLT exp;
+    MYFLT offset;
+    MYFLT currentVal;
     double currentTime;
     MYFLT sampleToSec;
 } Fader;
@@ -65,7 +67,7 @@ Fader_generate_auto(Fader *self) {
 
     for (i=0; i<self->bufsize; i++) {
         if (self->currentTime <= self->attack)
-            val = self->currentTime * iatt;
+            val = self->currentTime * iatt * (1.0 - self->offset) + self->offset;
         else if (self->currentTime > self->duration) {
             val = 0.;
             self->ended = 1;
@@ -75,7 +77,7 @@ Fader_generate_auto(Fader *self) {
         else
             val = 1.;
 
-        self->data[i] = val;
+        self->data[i] = self->currentVal = val;
         self->currentTime += self->sampleToSec;
     }
 
@@ -101,9 +103,8 @@ Fader_generate_wait(Fader *self) {
 
     for (i=0; i<self->bufsize; i++) {
         if (self->fademode == 0) {
-
             if (self->currentTime <= self->attack)
-                val = self->currentTime * iatt;
+                val = self->currentTime * iatt * (1.0 - self->offset) + self->offset;
             else
                 val = 1.;
             self->topValue = val;
@@ -114,7 +115,7 @@ Fader_generate_wait(Fader *self) {
             else
                 val = 0.;
         }
-        self->data[i] = val;
+        self->data[i] = self->currentVal = val;
         self->currentTime += self->sampleToSec;
     }
     
@@ -224,13 +225,13 @@ Fader_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
     self->duration = 0.0;
     self->exp = 1.0;
     self->currentTime = 0.0;
+    self->offset = 0.0;
+    self->currentVal = 0.0;
 
     INIT_OBJECT_COMMON
     Stream_setFunctionPtr(self->stream, Fader_compute_next_data_frame);
     self->mode_func_ptr = Fader_setProcMode;
 
-    Stream_setStreamActive(self->stream, 0);
-
     self->sampleToSec = 1. / self->sr;
 
     static char *kwlist[] = {"fadein", "fadeout", "dur", "mul", "add", NULL};
@@ -265,6 +266,7 @@ static PyObject * Fader_play(Fader *self, PyObject *args, PyObject *kwds)
     self->fademode = 0;
     self->ended = 0;
     self->currentTime = 0.0;
+    self->offset = self->currentVal;
     (*self->mode_func_ptr)(self);
     PLAY
 };
@@ -444,6 +446,8 @@ typedef struct {
     MYFLT release;
     MYFLT duration;
     MYFLT exp;
+    MYFLT offset;
+    MYFLT currentVal;
     double currentTime;
     MYFLT sampleToSec;
 } Adsr;
@@ -472,7 +476,7 @@ Adsr_generate_auto(Adsr *self) {
 
     for (i=0; i<self->bufsize; i++) {
         if (self->currentTime <= self->attack)
-            val = self->currentTime * invatt;
+            val = self->currentTime * invatt * (1.0 - self->offset) + self->offset;
         else if (self->currentTime <= (self->attack + self->decay))
             val = (self->decay - (self->currentTime - self->attack)) * invdec * (1. - self->sustain) + self->sustain;
         else if (self->currentTime > self->duration)
@@ -482,7 +486,7 @@ Adsr_generate_auto(Adsr *self) {
         else
             val = self->sustain;
 
-        self->data[i] = val;
+        self->data[i] = self->currentVal = val;
         self->currentTime += self->sampleToSec;
     }
 
@@ -507,9 +511,8 @@ Adsr_generate_wait(Adsr *self) {
 
     for (i=0; i<self->bufsize; i++) {
         if (self->fademode == 0) {
-
             if (self->currentTime <= self->attack)
-                val = self->currentTime * invatt;
+                val = self->currentTime * invatt * (1.0 - self->offset) + self->offset;
             else if (self->currentTime <= (self->attack + self->decay))
                 val = (self->decay - (self->currentTime - self->attack)) * invdec * (1. - self->sustain) + self->sustain;
             else
@@ -523,7 +526,7 @@ Adsr_generate_wait(Adsr *self) {
             else
                 val = 0.;
         }
-        self->data[i] = val;
+        self->data[i] = self->currentVal = val;
         self->currentTime += self->sampleToSec;
     }
 
@@ -634,13 +637,13 @@ Adsr_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
     self->duration = 0.0;
     self->exp = 1.0;
     self->currentTime = 0.0;
+    self->offset = 0.0;
+    self->currentVal = 0.0;
 
     INIT_OBJECT_COMMON
     Stream_setFunctionPtr(self->stream, Adsr_compute_next_data_frame);
     self->mode_func_ptr = Adsr_setProcMode;
 
-    Stream_setStreamActive(self->stream, 0);
-
     self->sampleToSec = 1. / self->sr;
 
     static char *kwlist[] = {"attack", "decay", "sustain", "release", "dur", "mul", "add", NULL};
@@ -685,6 +688,7 @@ static PyObject * Adsr_play(Adsr *self, PyObject *args, PyObject *kwds)
 {
     self->fademode = 0;
     self->currentTime = 0.0;
+    self->offset = self->currentVal;
     (*self->mode_func_ptr)(self);
     PLAY
 };
@@ -1072,8 +1076,6 @@ Linseg_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
     Stream_setFunctionPtr(self->stream, Linseg_compute_next_data_frame);
     self->mode_func_ptr = Linseg_setProcMode;
 
-    Stream_setStreamActive(self->stream, 0);
-
     self->sampleToSec = 1. / self->sr;
 
     static char *kwlist[] = {"list", "loop", "initToFirstVal", "mul", "add", NULL};
@@ -1489,8 +1491,6 @@ Expseg_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
     Stream_setFunctionPtr(self->stream, Expseg_compute_next_data_frame);
     self->mode_func_ptr = Expseg_setProcMode;
 
-    Stream_setStreamActive(self->stream, 0);
-
     self->sampleToSec = 1. / self->sr;
 
     static char *kwlist[] = {"list", "loop", "exp", "inverse", "initToFirstVal", "mul", "add", NULL};
