@@ -19,6 +19,7 @@
  *************************************************************************/
 
 #include <Python.h>
+#include "py2to3.h"
 #include "structmember.h"
 #include <math.h>
 #include "pyomodule.h"
@@ -613,7 +614,7 @@ Freeverb_dealloc(Freeverb* self)
         free(self->allpass_buf[i]);
     }
     Freeverb_clear(self);
-    self->ob_type->tp_free((PyObject*)self);
+    Py_TYPE(self)->tp_free((PyObject*)self);
 }
 
 static PyObject *
@@ -684,14 +685,14 @@ Freeverb_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
             self->comb_buf[i][j] = 0.0;
         }
     }
-        for(i=0; i<NUM_ALLPASS; i++) {
-            nsamps = Freeverb_calc_nsamples((Freeverb *)self, allpass_delays[i] + rndSamps);
-            self->allpass_buf[i] = (MYFLT *)realloc(self->allpass_buf[i], (nsamps+1) * sizeof(MYFLT));
-            self->allpass_nSamples[i] = nsamps;
-            self->allpass_bufPos[i] = 0;
-            for(j=0; j<nsamps; j++) {
-                self->allpass_buf[i][j] = 0.0;
-            }
+    for(i=0; i<NUM_ALLPASS; i++) {
+        nsamps = Freeverb_calc_nsamples((Freeverb *)self, allpass_delays[i] + rndSamps);
+        self->allpass_buf[i] = (MYFLT *)realloc(self->allpass_buf[i], (nsamps+1) * sizeof(MYFLT));
+        self->allpass_nSamples[i] = nsamps;
+        self->allpass_bufPos[i] = 0;
+        for(j=0; j<nsamps; j++) {
+            self->allpass_buf[i][j] = 0.0;
+        }
     }
 
     return (PyObject *)self;
@@ -717,6 +718,26 @@ static PyObject * Freeverb_inplace_sub(Freeverb *self, PyObject *arg) { INPLACE_
 static PyObject * Freeverb_div(Freeverb *self, PyObject *arg) { DIV };
 static PyObject * Freeverb_inplace_div(Freeverb *self, PyObject *arg) { INPLACE_DIV };
 
+static PyObject *
+Freeverb_reset(Freeverb *self)
+{
+    int i, j;
+    for(i=0; i<NUM_COMB; i++) {
+        self->comb_bufPos[i] = 0;
+        self->comb_filterState[i] = 0.0;
+        for(j=0; j<self->comb_nSamples[i]; j++) {
+            self->comb_buf[i][j] = 0.0;
+        }
+    }
+    for(i=0; i<NUM_ALLPASS; i++) {
+        self->allpass_bufPos[i] = 0;
+        for(j=0; j<self->allpass_nSamples[i]; j++) {
+            self->allpass_buf[i][j] = 0.0;
+        }
+    }
+	Py_RETURN_NONE;
+}
+
 static PyObject *
 Freeverb_setSize(Freeverb *self, PyObject *arg)
 {
@@ -827,6 +848,7 @@ static PyMethodDef Freeverb_methods[] = {
     {"play", (PyCFunction)Freeverb_play, METH_VARARGS|METH_KEYWORDS, "Starts computing without sending sound to soundcard."},
     {"out", (PyCFunction)Freeverb_out, METH_VARARGS|METH_KEYWORDS, "Starts computing and sends sound to soundcard channel speficied by argument."},
     {"stop", (PyCFunction)Freeverb_stop, METH_NOARGS, "Stops computing."},
+    {"reset", (PyCFunction)Freeverb_reset, METH_NOARGS, "Reset the delay lines."},
 	{"setSize", (PyCFunction)Freeverb_setSize, METH_O, "Sets distortion size factor (0 -> 1)."},
     {"setDamp", (PyCFunction)Freeverb_setDamp, METH_O, "Sets lowpass filter damp factor."},
     {"setMix", (PyCFunction)Freeverb_setMix, METH_O, "Sets the mix factor."},
@@ -841,7 +863,7 @@ static PyNumberMethods Freeverb_as_number = {
     (binaryfunc)Freeverb_add,                      /*nb_add*/
     (binaryfunc)Freeverb_sub,                 /*nb_subtract*/
     (binaryfunc)Freeverb_multiply,                 /*nb_multiply*/
-    (binaryfunc)Freeverb_div,                   /*nb_divide*/
+    INITIALIZE_NB_DIVIDE_ZERO               /*nb_divide*/
     0,                /*nb_remainder*/
     0,                   /*nb_divmod*/
     0,                   /*nb_power*/
@@ -855,16 +877,16 @@ static PyNumberMethods Freeverb_as_number = {
     0,              /*nb_and*/
     0,              /*nb_xor*/
     0,               /*nb_or*/
-    0,                                          /*nb_coerce*/
+    INITIALIZE_NB_COERCE_ZERO                   /*nb_coerce*/
     0,                       /*nb_int*/
     0,                      /*nb_long*/
     0,                     /*nb_float*/
-    0,                       /*nb_oct*/
-    0,                       /*nb_hex*/
+    INITIALIZE_NB_OCT_ZERO   /*nb_oct*/
+    INITIALIZE_NB_HEX_ZERO   /*nb_hex*/
     (binaryfunc)Freeverb_inplace_add,              /*inplace_add*/
     (binaryfunc)Freeverb_inplace_sub,         /*inplace_subtract*/
     (binaryfunc)Freeverb_inplace_multiply,         /*inplace_multiply*/
-    (binaryfunc)Freeverb_inplace_div,           /*inplace_divide*/
+    INITIALIZE_NB_IN_PLACE_DIVIDE_ZERO        /*inplace_divide*/
     0,        /*inplace_remainder*/
     0,           /*inplace_power*/
     0,       /*inplace_lshift*/
@@ -873,15 +895,14 @@ static PyNumberMethods Freeverb_as_number = {
     0,      /*inplace_xor*/
     0,       /*inplace_or*/
     0,             /*nb_floor_divide*/
-    0,              /*nb_true_divide*/
+    (binaryfunc)Freeverb_div,                       /*nb_true_divide*/
     0,     /*nb_inplace_floor_divide*/
-    0,      /*nb_inplace_true_divide*/
+    (binaryfunc)Freeverb_inplace_div,                       /*nb_inplace_true_divide*/
     0,                     /* nb_index */
 };
 
 PyTypeObject FreeverbType = {
-    PyObject_HEAD_INIT(NULL)
-    0,                         /*ob_size*/
+    PyVarObject_HEAD_INIT(NULL, 0)
     "_pyo.Freeverb_base",         /*tp_name*/
     sizeof(Freeverb),         /*tp_basicsize*/
     0,                         /*tp_itemsize*/
@@ -889,7 +910,7 @@ PyTypeObject FreeverbType = {
     0,                         /*tp_print*/
     0,                         /*tp_getattr*/
     0,                         /*tp_setattr*/
-    0,                         /*tp_compare*/
+    0,                         /*tp_as_async (tp_compare in Python 2)*/
     0,                         /*tp_repr*/
     &Freeverb_as_number,             /*tp_as_number*/
     0,                         /*tp_as_sequence*/
