@@ -19,6 +19,7 @@
  *************************************************************************/
 
 #include <Python.h>
+#include "py2to3.h"
 #include "structmember.h"
 #include <math.h>
 #include "pyomodule.h"
@@ -94,13 +95,13 @@ OscBank_setFrequencies(OscBank *self, MYFLT freq, MYFLT spread) {
             seed = (seed * 15625 + 1) & 0xFFFF;
             rnd = seed * 1.52587890625e-07 - 0.005 + 1.0;
             self->frequencies[i] = (freq + scl * i) * rnd;
-            /* printf("harm %d : %f Hz\n", i, self->frequencies[i]); */
+            /* PySys_WriteStdout("harm %d : %f Hz\n", i, self->frequencies[i]); */
         }
     }
     else {
         for (i=0; i<self->stages; i++) {
             self->frequencies[i] = freq + scl * i;
-            /* printf("harm %d : %f Hz\n", i, self->frequencies[i]); */
+            /* PySys_WriteStdout("harm %d : %f Hz\n", i, self->frequencies[i]); */
         }
     }
 }
@@ -405,7 +406,7 @@ OscBank_dealloc(OscBank* self)
     free(self->aValues);
     free(self->aDiffs);
     OscBank_clear(self);
-    self->ob_type->tp_free((PyObject*)self);
+    Py_TYPE(self)->tp_free((PyObject*)self);
 }
 
 static PyObject *
@@ -815,7 +816,7 @@ static PyNumberMethods OscBank_as_number = {
     (binaryfunc)OscBank_add,                         /*nb_add*/
     (binaryfunc)OscBank_sub,                         /*nb_subtract*/
     (binaryfunc)OscBank_multiply,                    /*nb_multiply*/
-    (binaryfunc)OscBank_div,                                              /*nb_divide*/
+    INITIALIZE_NB_DIVIDE_ZERO                       /*nb_divide*/
     0,                                              /*nb_remainder*/
     0,                                              /*nb_divmod*/
     0,                                              /*nb_power*/
@@ -829,16 +830,16 @@ static PyNumberMethods OscBank_as_number = {
     0,                                              /*nb_and*/
     0,                                              /*nb_xor*/
     0,                                              /*nb_or*/
-    0,                                              /*nb_coerce*/
+    INITIALIZE_NB_COERCE_ZERO                       /*nb_coerce*/
     0,                                              /*nb_int*/
     0,                                              /*nb_long*/
     0,                                              /*nb_float*/
-    0,                                              /*nb_oct*/
-    0,                                              /*nb_hex*/
+    INITIALIZE_NB_OCT_ZERO                          /*nb_oct*/
+    INITIALIZE_NB_HEX_ZERO                          /*nb_hex*/
     (binaryfunc)OscBank_inplace_add,                 /*inplace_add*/
     (binaryfunc)OscBank_inplace_sub,                 /*inplace_subtract*/
     (binaryfunc)OscBank_inplace_multiply,            /*inplace_multiply*/
-    (binaryfunc)OscBank_inplace_div,                                              /*inplace_divide*/
+    INITIALIZE_NB_IN_PLACE_DIVIDE_ZERO                                           /*inplace_divide*/
     0,                                              /*inplace_remainder*/
     0,                                              /*inplace_power*/
     0,                                              /*inplace_lshift*/
@@ -847,15 +848,14 @@ static PyNumberMethods OscBank_as_number = {
     0,                                              /*inplace_xor*/
     0,                                              /*inplace_or*/
     0,                                              /*nb_floor_divide*/
-    0,                                              /*nb_true_divide*/
+    (binaryfunc)OscBank_div,                       /*nb_true_divide*/
     0,                                              /*nb_inplace_floor_divide*/
-    0,                                              /*nb_inplace_true_divide*/
+    (binaryfunc)OscBank_inplace_div,                       /*nb_inplace_true_divide*/
     0,                                              /* nb_index */
 };
 
 PyTypeObject OscBankType = {
-    PyObject_HEAD_INIT(NULL)
-    0,                                              /*ob_size*/
+    PyVarObject_HEAD_INIT(NULL, 0)
     "_pyo.OscBank_base",                                   /*tp_name*/
     sizeof(OscBank),                                 /*tp_basicsize*/
     0,                                              /*tp_itemsize*/
@@ -863,7 +863,7 @@ PyTypeObject OscBankType = {
     0,                                              /*tp_print*/
     0,                                              /*tp_getattr*/
     0,                                              /*tp_setattr*/
-    0,                                              /*tp_compare*/
+    0,                                              /*tp_as_async (tp_compare in Python 2)*/
     0,                                              /*tp_repr*/
     &OscBank_as_number,                              /*tp_as_number*/
     0,                                              /*tp_as_sequence*/
