@@ -176,8 +176,6 @@ Pattern_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
     Stream_setFunctionPtr(self->stream, Pattern_compute_next_data_frame);
     self->mode_func_ptr = Pattern_setProcMode;
 
-    Stream_setStreamActive(self->stream, 0);
-
     self->sampleToSec = 1. / self->sr;
     self->currentTime = 0.;
 
@@ -531,7 +529,8 @@ CallAfter_generate(CallAfter *self) {
             result = PyObject_Call(self->callable, tuple, NULL);
             if (result == NULL)
                 PyErr_Print();
-            PyObject_CallMethod((PyObject *)self, "stop", NULL);
+            if (self->stream != NULL)
+                PyObject_CallMethod((PyObject *)self, "stop", NULL);
             break;
         }
         self->currentTime += self->sampleToSec;
