@@ -274,6 +274,7 @@ static PyObject *
 SfPlayer_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
 {
     int i;
+    Py_ssize_t psize;
     MYFLT offset = 0.;
     PyObject *speedtmp=NULL;
     SfPlayer *self;
@@ -291,7 +292,7 @@ SfPlayer_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
 
     static char *kwlist[] = {"path", "speed", "loop", "offset", "interp", NULL};
 
-    if (! PyArg_ParseTupleAndKeywords(args, kwds, TYPE_S__OIFI, kwlist, &self->path, &speedtmp, &self->loop, &offset, &self->interp))
+    if (! PyArg_ParseTupleAndKeywords(args, kwds, TYPE_P__OIFI, kwlist, &self->path, &psize, &speedtmp, &self->loop, &offset, &self->interp))
         Py_RETURN_NONE;
 
     if (speedtmp) {
@@ -386,14 +387,18 @@ SfPlayer_setSpeed(SfPlayer *self, PyObject *arg)
 }
 
 static PyObject *
-SfPlayer_setSound(SfPlayer *self, PyObject *arg)
+SfPlayer_setSound(SfPlayer *self, PyObject *args)
 {
     /* Need to perform a check to be sure that the new 
        sound is of the same number of channels. */
+    Py_ssize_t psize;
 
-    ASSERT_ARG_NOT_NULL
+    //ASSERT_ARG_NOT_NULL
 
-    self->path = PY_STRING_AS_STRING(arg);
+    if (! PyArg_ParseTuple(args, "s#", &self->path, &psize))
+        Py_RETURN_NONE;
+
+    //self->path = PY_STRING_AS_STRING(arg);
 
     sf_close(self->sf);
 
@@ -480,7 +485,7 @@ static PyMethodDef SfPlayer_methods[] = {
 {"play", (PyCFunction)SfPlayer_play, METH_VARARGS|METH_KEYWORDS, "Starts computing without sending sound to soundcard."},
 {"out", (PyCFunction)SfPlayer_out, METH_VARARGS|METH_KEYWORDS, "Starts computing and sends sound to soundcard channel speficied by argument."},
 {"stop", (PyCFunction)SfPlayer_stop, METH_NOARGS, "Stops computing."},
-{"setSound", (PyCFunction)SfPlayer_setSound, METH_O, "Sets sfplayer sound path."},
+{"setSound", (PyCFunction)SfPlayer_setSound, METH_VARARGS, "Sets sfplayer sound path."},
 {"setSpeed", (PyCFunction)SfPlayer_setSpeed, METH_O, "Sets sfplayer reading speed."},
 {"setLoop", (PyCFunction)SfPlayer_setLoop, METH_O, "Sets sfplayer loop mode (0 = no loop, 1 = loop)."},
 {"setOffset", (PyCFunction)SfPlayer_setOffset, METH_O, "Sets sfplayer start position."},
@@ -1181,6 +1186,7 @@ static PyObject *
 SfMarkerShuffler_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
 {
     int i;
+    Py_ssize_t psize;
     PyObject *speedtmp=NULL, *markerstmp=NULL;
     SfMarkerShuffler *self;
     self = (SfMarkerShuffler *)type->tp_alloc(type, 0);
@@ -1198,7 +1204,7 @@ SfMarkerShuffler_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
 
     static char *kwlist[] = {"path", "markers", "speed", "interp", NULL};
 
-    if (! PyArg_ParseTupleAndKeywords(args, kwds, "sO|Oi", kwlist, &self->path, &markerstmp, &speedtmp, &self->interp))
+    if (! PyArg_ParseTupleAndKeywords(args, kwds, "s#O|Oi", kwlist, &self->path, &psize, &markerstmp, &speedtmp, &self->interp))
         Py_RETURN_NONE;
 
     if (speedtmp) {
@@ -1988,6 +1994,7 @@ static PyObject *
 SfMarkerLooper_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
 {
     int i;
+    Py_ssize_t psize;
     PyObject *speedtmp=NULL, *marktmp=NULL, *markerstmp=NULL;
     SfMarkerLooper *self;
     self = (SfMarkerLooper *)type->tp_alloc(type, 0);
@@ -2008,7 +2015,7 @@ SfMarkerLooper_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
 
     static char *kwlist[] = {"path", "markers", "speed", "mark", "interp", NULL};
 
-    if (! PyArg_ParseTupleAndKeywords(args, kwds, "sO|OOi", kwlist, &self->path, &markerstmp, &speedtmp, &marktmp, &self->interp))
+    if (! PyArg_ParseTupleAndKeywords(args, kwds, "s#O|OOi", kwlist, &self->path, &psize, &markerstmp, &speedtmp, &marktmp, &self->interp))
         Py_RETURN_NONE;
 
     if (speedtmp) {
