@@ -19,6 +19,7 @@
  *************************************************************************/
 
 #include <Python.h>
+#include "py2to3.h"
 #include "structmember.h"
 #include <math.h>
 #include "pyomodule.h"
@@ -472,7 +473,7 @@ WGVerb_dealloc(WGVerb* self)
         free(self->buffer[i]);
     }
     WGVerb_clear(self);
-    self->ob_type->tp_free((PyObject*)self);
+    Py_TYPE(self)->tp_free((PyObject*)self);
 }
 
 static PyObject *
@@ -572,6 +573,22 @@ static PyObject * WGVerb_inplace_sub(WGVerb *self, PyObject *arg) { INPLACE_SUB
 static PyObject * WGVerb_div(WGVerb *self, PyObject *arg) { DIV };
 static PyObject * WGVerb_inplace_div(WGVerb *self, PyObject *arg) { INPLACE_DIV };
 
+static PyObject *
+WGVerb_reset(WGVerb *self)
+{
+    int i, j;
+    for (i=0; i<8; i++) {
+        self->in_count[i] = 0;
+        self->lastSamples[i] = 0.0;
+        for (j=0; j<(self->size[i]+1); j++) {
+            self->buffer[i][j] = 0.;
+        }
+    }
+    self->total_signal = 0.0;
+
+	Py_RETURN_NONE;
+}
+
 static PyObject *
 WGVerb_setFeedback(WGVerb *self, PyObject *arg)
 {
@@ -683,6 +700,7 @@ static PyMethodDef WGVerb_methods[] = {
 {"play", (PyCFunction)WGVerb_play, METH_VARARGS|METH_KEYWORDS, "Starts computing without sending sound to soundcard."},
 {"out", (PyCFunction)WGVerb_out, METH_VARARGS|METH_KEYWORDS, "Starts computing and sends sound to soundcard channel speficied by argument."},
 {"stop", (PyCFunction)WGVerb_stop, METH_NOARGS, "Stops computing."},
+{"reset", (PyCFunction)WGVerb_reset, METH_NOARGS, "Reset the delay line."},
 {"setFeedback", (PyCFunction)WGVerb_setFeedback, METH_O, "Sets feedback value between 0 -> 1."},
 {"setCutoff", (PyCFunction)WGVerb_setCutoff, METH_O, "Sets lowpass filter cutoff."},
 {"setMix", (PyCFunction)WGVerb_setMix, METH_O, "Sets balance between dry and wet signals."},
@@ -697,7 +715,7 @@ static PyNumberMethods WGVerb_as_number = {
 (binaryfunc)WGVerb_add,                      /*nb_add*/
 (binaryfunc)WGVerb_sub,                 /*nb_subtract*/
 (binaryfunc)WGVerb_multiply,                 /*nb_multiply*/
-(binaryfunc)WGVerb_div,                   /*nb_divide*/
+INITIALIZE_NB_DIVIDE_ZERO               /*nb_divide*/
 0,                /*nb_remainder*/
 0,                   /*nb_divmod*/
 0,                   /*nb_power*/
@@ -711,16 +729,16 @@ static PyNumberMethods WGVerb_as_number = {
 0,              /*nb_and*/
 0,              /*nb_xor*/
 0,               /*nb_or*/
-0,                                          /*nb_coerce*/
+INITIALIZE_NB_COERCE_ZERO                   /*nb_coerce*/
 0,                       /*nb_int*/
 0,                      /*nb_long*/
 0,                     /*nb_float*/
-0,                       /*nb_oct*/
-0,                       /*nb_hex*/
+INITIALIZE_NB_OCT_ZERO   /*nb_oct*/
+INITIALIZE_NB_HEX_ZERO   /*nb_hex*/
 (binaryfunc)WGVerb_inplace_add,              /*inplace_add*/
 (binaryfunc)WGVerb_inplace_sub,         /*inplace_subtract*/
 (binaryfunc)WGVerb_inplace_multiply,         /*inplace_multiply*/
-(binaryfunc)WGVerb_inplace_div,           /*inplace_divide*/
+INITIALIZE_NB_IN_PLACE_DIVIDE_ZERO        /*inplace_divide*/
 0,        /*inplace_remainder*/
 0,           /*inplace_power*/
 0,       /*inplace_lshift*/
@@ -729,15 +747,14 @@ static PyNumberMethods WGVerb_as_number = {
 0,      /*inplace_xor*/
 0,       /*inplace_or*/
 0,             /*nb_floor_divide*/
-0,              /*nb_true_divide*/
+(binaryfunc)WGVerb_div,                       /*nb_true_divide*/
 0,     /*nb_inplace_floor_divide*/
-0,      /*nb_inplace_true_divide*/
+(binaryfunc)WGVerb_inplace_div,                       /*nb_inplace_true_divide*/
 0,                     /* nb_index */
 };
 
 PyTypeObject WGVerbType = {
-PyObject_HEAD_INIT(NULL)
-0,                         /*ob_size*/
+PyVarObject_HEAD_INIT(NULL, 0)
 "_pyo.WGVerb_base",         /*tp_name*/
 sizeof(WGVerb),         /*tp_basicsize*/
 0,                         /*tp_itemsize*/
@@ -745,7 +762,7 @@ sizeof(WGVerb),         /*tp_basicsize*/
 0,                         /*tp_print*/
 0,                         /*tp_getattr*/
 0,                         /*tp_setattr*/
-0,                         /*tp_compare*/
+0,                         /*tp_as_async (tp_compare in Python 2)*/
 0,                         /*tp_repr*/
 &WGVerb_as_number,             /*tp_as_number*/
 0,                         /*tp_as_sequence*/
@@ -1446,7 +1463,7 @@ STReverb_dealloc(STReverb* self)
     }
     free(self->buffer_streams);
     STReverb_clear(self);
-    self->ob_type->tp_free((PyObject*)self);
+    Py_TYPE(self)->tp_free((PyObject*)self);
 }
 
 static PyObject *
@@ -1565,6 +1582,42 @@ static PyObject * STReverb_getStream(STReverb* self) { GET_STREAM };
 static PyObject * STReverb_play(STReverb *self, PyObject *args, PyObject *kwds) { PLAY };
 static PyObject * STReverb_stop(STReverb *self) { STOP };
 
+static PyObject *
+STReverb_reset(STReverb *self)
+{
+    int i, j, k, maxsize;
+    
+    for (k=0; k<2; k++) {
+        for (i=0; i<8; i++) {
+            self->in_count[k][i] = 0;
+            self->lastSamples[k][i] = 0.0;
+            for (j=0; j<self->size[k][i]; j++) {
+                self->buffer[k][i][j] = 0.;
+            }
+        }
+    }
+    for (k=0; k<NUM_REFS; k++) {
+        self->ref_in_count[k] = 0;
+        maxsize = (int)(first_ref_delays[k] * self->srfac * 4.0 + 0.5);
+        for (i=0; i<(maxsize+1); i++) {
+            self->ref_buffer[k][i] = 0.0;
+        }
+    }
+    for (k=0; k<2; k++) {
+        for (i=0; i<self->bufsize; i++) {
+            self->input_buffer[k][i] = 0.0;
+        }
+    }
+
+    for (i=0; i<(2 * self->bufsize); i++) {
+        self->buffer_streams[i] = 0.0;
+    }
+
+    self->total_signal[0] = self->total_signal[1] = 0.0;
+
+	Py_RETURN_NONE;
+}
+
 static PyObject *
 STReverb_setInpos(STReverb *self, PyObject *arg)
 {
@@ -1774,6 +1827,7 @@ static PyMethodDef STReverb_methods[] = {
 {"_getStream", (PyCFunction)STReverb_getStream, METH_NOARGS, "Returns stream object."},
 {"play", (PyCFunction)STReverb_play, METH_VARARGS|METH_KEYWORDS, "Starts computing without sending sound to soundcard."},
 {"stop", (PyCFunction)STReverb_stop, METH_NOARGS, "Stops computing."},
+{"reset", (PyCFunction)STReverb_reset, METH_NOARGS, "Reset the delay line."},
 {"setInpos", (PyCFunction)STReverb_setInpos, METH_O, "Sets position of the source between 0 -> 1."},
 {"setRevtime", (PyCFunction)STReverb_setRevtime, METH_O, "Sets reverb duration in seconds."},
 {"setCutoff", (PyCFunction)STReverb_setCutoff, METH_O, "Sets lowpass filter cutoff."},
@@ -1784,8 +1838,7 @@ static PyMethodDef STReverb_methods[] = {
 };
 
 PyTypeObject STReverbType = {
-PyObject_HEAD_INIT(NULL)
-0,                         /*ob_size*/
+PyVarObject_HEAD_INIT(NULL, 0)
 "_pyo.STReverb_base",         /*tp_name*/
 sizeof(STReverb),         /*tp_basicsize*/
 0,                         /*tp_itemsize*/
@@ -1793,7 +1846,7 @@ sizeof(STReverb),         /*tp_basicsize*/
 0,                         /*tp_print*/
 0,                         /*tp_getattr*/
 0,                         /*tp_setattr*/
-0,                         /*tp_compare*/
+0,                         /*tp_as_async (tp_compare in Python 2)*/
 0,                         /*tp_repr*/
 0,             /*tp_as_number*/
 0,                         /*tp_as_sequence*/
@@ -1916,7 +1969,7 @@ STRev_dealloc(STRev* self)
 {
     pyo_DEALLOC
     STRev_clear(self);
-    self->ob_type->tp_free((PyObject*)self);
+    Py_TYPE(self)->tp_free((PyObject*)self);
 }
 
 static PyObject *
@@ -2003,7 +2056,7 @@ static PyNumberMethods STRev_as_number = {
 (binaryfunc)STRev_add,                      /*nb_add*/
 (binaryfunc)STRev_sub,                 /*nb_subtract*/
 (binaryfunc)STRev_multiply,                 /*nb_multiply*/
-(binaryfunc)STRev_div,                   /*nb_divide*/
+INITIALIZE_NB_DIVIDE_ZERO               /*nb_divide*/
 0,                /*nb_remainder*/
 0,                   /*nb_divmod*/
 0,                   /*nb_power*/
@@ -2017,16 +2070,16 @@ static PyNumberMethods STRev_as_number = {
 0,              /*nb_and*/
 0,              /*nb_xor*/
 0,               /*nb_or*/
-0,                                          /*nb_coerce*/
+INITIALIZE_NB_COERCE_ZERO                   /*nb_coerce*/
 0,                       /*nb_int*/
 0,                      /*nb_long*/
 0,                     /*nb_float*/
-0,                       /*nb_oct*/
-0,                       /*nb_hex*/
+INITIALIZE_NB_OCT_ZERO   /*nb_oct*/
+INITIALIZE_NB_HEX_ZERO   /*nb_hex*/
 (binaryfunc)STRev_inplace_add,              /*inplace_add*/
 (binaryfunc)STRev_inplace_sub,         /*inplace_subtract*/
 (binaryfunc)STRev_inplace_multiply,         /*inplace_multiply*/
-(binaryfunc)STRev_inplace_div,           /*inplace_divide*/
+INITIALIZE_NB_IN_PLACE_DIVIDE_ZERO        /*inplace_divide*/
 0,        /*inplace_remainder*/
 0,           /*inplace_power*/
 0,       /*inplace_lshift*/
@@ -2035,15 +2088,14 @@ static PyNumberMethods STRev_as_number = {
 0,      /*inplace_xor*/
 0,       /*inplace_or*/
 0,             /*nb_floor_divide*/
-0,              /*nb_true_divide*/
+(binaryfunc)STRev_div,                       /*nb_true_divide*/
 0,     /*nb_inplace_floor_divide*/
-0,      /*nb_inplace_true_divide*/
+(binaryfunc)STRev_inplace_div,                       /*nb_inplace_true_divide*/
 0,                     /* nb_index */
 };
 
 PyTypeObject STRevType = {
-PyObject_HEAD_INIT(NULL)
-0,                         /*ob_size*/
+PyVarObject_HEAD_INIT(NULL, 0)
 "_pyo.STRev_base",         /*tp_name*/
 sizeof(STRev),         /*tp_basicsize*/
 0,                         /*tp_itemsize*/
@@ -2051,7 +2103,7 @@ sizeof(STRev),         /*tp_basicsize*/
 0,                         /*tp_print*/
 0,                         /*tp_getattr*/
 0,                         /*tp_setattr*/
-0,                         /*tp_compare*/
+0,                         /*tp_as_async (tp_compare in Python 2)*/
 0,                         /*tp_repr*/
 &STRev_as_number,             /*tp_as_number*/
 0,                         /*tp_as_sequence*/
